pub trait ClusterStreamExt: Stream {
// Provided methods
fn take_during(self, duration: Duration) -> TakeDuring<Self>
where Self::Item: TimestampEvent,
Self: TimestampSource + Sized { ... }
fn map_errors(
self,
is_error: fn(&Self::Item) -> bool,
) -> MapErrors<Self, Self::Item>
where Self: Sized { ... }
fn try_any_with_rust<F>(self, f: F) -> TryAnyWithRustNode<Self, F> ⓘ
where Self: Sized + TryStream,
F: FnMut(RustNodeId, RustNodeEvent, &P2pState) -> bool { ... }
}Provided Methods
Sourcefn take_during(self, duration: Duration) -> TakeDuring<Self>
fn take_during(self, duration: Duration) -> TakeDuring<Self>
Take events during specified period of time.
Sourcefn map_errors(
self,
is_error: fn(&Self::Item) -> bool,
) -> MapErrors<Self, Self::Item>where
Self: Sized,
fn map_errors(
self,
is_error: fn(&Self::Item) -> bool,
) -> MapErrors<Self, Self::Item>where
Self: Sized,
Maps events to ``Result, according to the is_error` output.
Sourcefn try_any_with_rust<F>(self, f: F) -> TryAnyWithRustNode<Self, F> ⓘ
fn try_any_with_rust<F>(self, f: F) -> TryAnyWithRustNode<Self, F> ⓘ
Attempts to execute a predicate over an event stream and evaluate if any rust node event and state satisfy the predicate.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".